.. _swh-vault:

Software Heritage - Vault
=========================

User-facing service that allows to retrieve parts of the archive as
self-contained bundles (e.g., individual releases, entire repository snapshots,
etc.)


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting-started.rst
   api.rst


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   cli
   /apidoc/swh.vault
